TWDA

# Tournament Winning Deck Archive

A test version of the TWDA with only 20 decks. This snapshot could be refreshed from time to time.

You can jump to the end of a year that interests you:
| 2020 |

Some abbreviations are used throughout the archive:

NC | National Championship | NAC | North American (Continental) Championship
NCQ | National Championship Qualifier | SAC | South American (Continental) Championship
ECQ | European Championship Qualifier | EC | European (Continental) Championship
CCQ | Continental Championship Qualifier | ACC | Asian Continental Championship

### 2020

Cicero Jannyson's I Torneio beneficente 2020: Fortaleza, Brazil October 2020
Lasse Poyry's 3rd Great Symposium: Mikkeli, Finland October 2020
Martin Mirza's Silesia by Night: Katowice, Poland September 2020
Moacir Júnior's Abactor: Fortaleza, Brazil September 2020
Tomàs López Jiménez's MitBlutSpielen jupiterbcn: Barcelona, Spain September 2020
Niko Vanhatalo's Black Forest Base 3: Hyvinkää, Finland September 2020
Lucas Raphael's Aniversário do Biell: Fortaleza, Brazil August 2020
Łukasz Ho Thanh's Return from Torpor: Gdynia, Poland August 2020
Lucas Raphael's Skaald: Fortaleza, Brazil August 2020
Juan Luís Molina's Padawan's Tournament II: Palma de Mallorca, Spain August 2020
Cicero Jannyson's O Despertar de Fortaleza, Brazil August 2020
Tommi Hakomaa's Garou Rim: Antediluvian Awakening: Joensuu, Finland August 2020
Otso Saariluoma's 4th Elder Library War: Espoo, Finland July 2020
Joachim Randa's Crusade: Moss, Norway July 2020
Moisés Ferrer's Summer Moon: Palma de Mallorca, Spain June 2020
Nikica Novakovic's Advent of Gehenna: Kragujevac, Serbia June 2020
Esa-Matti Smolander's Road to EC: Field Training: Joensuu, Finland March 2020
Łukasz Ho Thanh's Birthday Blood Party: Szczecin, Poland March 2020
Cicero Jannyson's Revolutionary Council: Fortaleza, Brazil March 2020
Antonio Seguí's Life is a Samedi: Palma de Mallorca, Spain March 2020
Top

    I Torneio beneficente 2020
    Fortaleza, Brazil
    October 11th 2020
    2R+F
    14 players
    Cicero Jannyson
    http://www.vekn.net/event-calendar/event/9702

    -- 2gw9 + 4vp in the final

    Deck Name: War ghoul anarch
    Author:
    Description:

    Crypt (12 cards, min=4, max=32, avg=4.08)
    -----------------------------------------
    5x Anarch Convert	1   -none-		Caitiff:ANY
    4x Nana Buruku		8   ANI POT PRE		Guruhi:4
    1x Ana Rita Montaña	5   VIC aus dom obf	Tzimisce:3
    1x Jane Sims		4   VIC ani aus pro	Tzimisce:4
    1x Droescher One-Eye	3   ani vic		Tzimisce:4

    Library (71 cards)
    Master (40; 2 trifle)
    4x Anarch Revolt
    9x Ashur Tablets
    2x Direct Intervention
    5x Jake Washington
    1x KRCG News Radio
    5x Parthenon, The
    9x Piper
    2x Twilight Camp
    2x Vessel
    1x WMRH Talk Radio

    Ally (18)
    6x Asanbonsam Ghoul
    2x Underbridge Stray
    2x Vagabond Mystic
    8x War Ghoul

    Retainer (2)
    1x J. S. Simmons, Esq.
    1x Mr. Winthrop

    Combat (8)
    4x Target Vitals
    4x Trap

    Event (3)
    1x FBI Special Affairs Division
    2x Unmasking, The

Top

    3rd Great Symposium
    Mikkeli, Finland
    October 3rd 2020
    3R+F
    13 players
    Lasse Poyry
    http://www.vekn.net/event-calendar/event/9668

    -- 1gw4 + 3vp in the final

    I wanted to make a deck that a) would not be easily ousted b) would guarantee that games will not go to time. So, Shatter the Gates with MMA gains it was.

    First round started quite nicely and I delivered shattered counters early on. Unfortunately Peetu also got his game running fast, gaining with Kaymakli fragment and voting damage. 1vp for me, not a disaster, but less than I was hoping for.

    Second round was terrible. Again, I was playing the table to Peetu, who was my prey. I couldn´t defend my shatter the gates and still I was stubbornly trying to play them. 0vp, and another GW for Peetu.

    Third round saved the day. If i recall correctly, I didn´t get shatters, but gained enough, bled enough, talked enough to manage a GW and place in the final table. Close call and a bleeding race with Pasi in the end.

    In the finals seating was me -> Tero (Malgorzata/Lord Tremere/Mistress Fanchon) -> Peetu (Giotto Verducci/Nos princes) -> Tom (Unnamed) -> Emma (Ventrue). From earlier rounds it was obvious that Peetu was the table threat. Also it seemed that Teros deck was not fast enough to put any pressure and there was very little that Tom could do backwards to Peetu.

    I decided to not play shatters at all. Instead, we had a similar understanding of the table with Emma; Tom had to go first, then we would do anything to help Tero oust Peetu. After that, hopefully I could oust Tero and we both would have a chance to win the game (and tournee).

    Plan worked like a charm. Close call though and (don´t qiute remember the details, but) coordinating bounces and well timed DI was needed as very often is the case. Great Beast helped a lot. In the end I think I had Cybele, Beastie, Veneficti and legionnaires to bleed and liquidation/Ashurs running nicely and duel with Emma was quite easy at that point.

    Finals thought of the deck.
    It was kinda fun to play for a while. Liquidation/Ashurs are way too strong and i wont be playing those without a really good reason. Babalawo is awesome. And so is the Great Beast. Those I most definetily will be playing a lot more and in different kind of decks. I was mostly worried about combat decks and surviving with direct rushes. I was lucky I guess, since I really don´t recall a tournament in which there was less combat than in this one, (I think Ari´s trap/blight was the only combat deck I saw).

    All in all, it was nice to play a tournament and it seemes that we have to wait a while until the next opportunity. I´ll be more than happy to "organize" (host really) tournaments in the same venue.

    Crypt (12 cards, min=26, max=40, avg=8.42)
    ------------------------------------------
    5x Cybele	   10  ANI DAI OBF PRE SER THA	Baali:4
    3x Babalawo Alafin 7   AUS FOR NEC ani		Harbinger of Skulls:4
    2x Nana Buruku	   8   ANI POT PRE		Guruhi:4
    1x Aksinya Daclau  9   ANI FOR PRE PRO cel tha	Gangrel antitribu:4
    1x Ruxandra	   5   OBF ani aus		Nosferatu:5

    Library (90 cards)
    Master (41; 9 trifle)
    12x Ashur Tablets
    1x Barrens, The
    1x Direct Intervention
    1x Dummy Corporation
    1x Failsafe
    1x From a Sinking Ship
    2x Golconda: Inner Peace
    5x Liquidation
    1x Major Boon
    1x Monastery of Shadows
    1x Secure Haven
    5x Villein
    1x Wash
    2x Wider View
    6x Zillah's Valley

    Action (16)
    1x Call the Great Beast
    2x Entrancement
    10x Shatter the Gate
    3x Unleash Hell's Fury

    Ally (6)
    4x Emerald Legionnaire
    1x Mylan Horseed
    1x Veneficti

    Action Modifier (11)
    2x Cloak the Gathering
    2x Elder Impersonation
    1x Faceless Night
    2x I am Legion
    2x Lost in Crowds
    2x Spying Mission

    Action Modifier/Combat (2)
    2x Swallowed by the Night

    Action Modifier/Reaction (3)
    3x Sense the Sin

    Reaction (7)
    1x Cats' Guidance
    2x My Enemy's Enemy
    2x Sense the Savage Way
    2x Telepathic Misdirection

    Combat (4)
    1x Conflagration
    1x Flames of the Netherworld
    2x Majesty

Top

    Silesia by Night
    Katowice, Poland
    September 26th 2020
    3R+F
    21 players
    Martin Mirza
    http://www.vekn.net/event-calendar/event/9697

    -- 2gw6 + 4vp in the final

    Deck Name: Better Call Saulot
    Author: Michał Misztal
    Description: Tweak of http://vtes.pl/forum/index.php?topic=4502.0 (-1 meat hook, -1 info highway, +2 sudden)

    Crypt (12 cards, min=10, max=44, avg=5.92)
    ------------------------------------------
    4x Saulot, The Wanderer	11  AUS FOR OBE THA VAL dai	Salubri:4
    2x Neighbor John	5   AUS dom for			Ventrue antitribu:4
    1x Maldavis (ADV)	4   AUS for pre			Caitiff:3
    1x Lana Butcher		3   dom for			Ventrue:3
    1x Rosemarie		3   FOR mel			Daughter of Cacophony:4
    1x Ulrike Rothbart	3   dom for			Ventrue antitribu:4
    1x Aimee Laroux		2   for pre			Daughter of Cacophony:4
    1x Sarah Raines		2   for				Gangrel:3

    Library (90 cards)
    Master (12; 2 trifle)
    2x Dreams of the Sphinx
    1x Heidelberg Castle, Germany
    1x Jake Washington
    2x Pentex(TM) Subversion
    1x Powerbase: Montreal
    1x Rack, The
    2x Sudden Reversal
    2x Wider View

    Action (8)
    4x Magic of the Smith
    4x Spirit Marionette

    Ally (1)
    1x Mylan Horseed

    Equipment (3)
    1x Bowl of Convergence
    1x Heart of Nizchetus
    1x Light Intensifying Goggles

    Action Modifier (3)
    1x Daring the Dawn
    2x Repulsion

    Reaction (35)
    7x Eagle's Sight
    12x Eyes of Argus
    4x Forced Awakening
    2x My Enemy's Enemy
    5x On the Qui Vive
    5x Telepathic Misdirection

    Combat (28)
    10x Anesthetic Touch
    7x Hidden Strength
    4x Target Vitals
    7x Unflinching Persistence

Top

    Abactor
    Fortaleza, Brazil
    September 13th 2020
    2R+F
    10 players
    Moacir Júnior
    http://www.vekn.net/event-calendar/event/9684

    -- 1gw4 + 2vp in the final

    Deck Name: Robbing & Rapeing
    Author: Moacir Rodrigues Jr
    Description: No violence

    Crypt (12 cards, min=39, max=44, avg=10.5)
    ------------------------------------------
    5x Mistress Fanchon		11  AUS CEL DOM OBF THA VIC	inner circle	Tremere:4
    1x Elimelech the Twice-Damned	11  AUS DEM DOM FOR OBF pro			Ventrue antitribu:5
    1x Rafael de Corazon		11  AUS CEL DOM OBF PRE		inner circle	Toreador:4
    1x Alonso Petrodon		10  ANI DOM OBF POT for tha	justicar	Nosferatu:5
    1x Gabrielle di Righetti	10  ANI AUS DOM THA obf pot	justicar	Tremere:5
    1x Luna Giovanni		10  DOM NEC OBF OBT POT cel	1 vote		Giovanni:5
    1x Servius Marius Pustula	10  ANI CHI DOM OBT POT obf			Nosferatu antitribu:4
    1x Orlando Oriundus		9   AUS DOM THA obf		bishop		Tremere antitribu:4

    Library (90 cards)
    Master (20; 5 trifle)
    6x Ashur Tablets
    1x Cavalier
    1x Dreams of the Sphinx
    1x Golconda: Inner Peace
    2x Heidelberg Castle, Germany
    1x Metro Underground
    1x Monastery of Shadows
    2x Protean
    4x Villein
    1x Wash

    Action (16)
    1x Abactor
    1x Dominate Kine
    1x Dual Form
    1x Far Mastery
    2x Govern the Unaligned
    1x Magic of the Smith
    7x Mind Rape
    1x Name Forgotten, The
    1x Rutor's Hand

    Equipment (5)
    1x AK-47
    1x Heart of Nizchetus
    1x Helicopter
    1x Palatial Estate
    1x Signet of King Saul, The

    Political Action (8)
    1x Alastor
    1x Ancient Influence
    1x Ancilla Empowerment
    1x Banishment
    1x Disputed Territory
    1x Kindred Segregation
    1x Political Stranglehold
    1x Reins of Power

    Action Modifier (20)
    2x Cloak the Gathering
    1x Conditioning
    4x Elder Impersonation
    1x Enkil Cog
    2x Faceless Night
    3x Forgotten Labyrinth
    1x Horrific Countenance
    3x Into Thin Air
    3x Seduction

    Action Modifier/Reaction (1)
    1x Murmur of the False Will

    Reaction (19)
    3x Deflection
    1x Eluding the Arms of Morpheus
    3x Eyes of Argus
    1x My Enemy's Enemy
    5x Obedience
    4x On the Qui Vive
    1x Redirection
    1x Telepathic Misdirection

    Event (1)
    1x Scourge of the Enochians

Top

    MitBlutSpielen jupiterbcn
    Barcelona, Spain
    September 12th 2020
    3R+F
    12 players
    Tomàs López Jiménez
    http://www.vekn.net/event-calendar/event/9679

    -- 1gw4 + 2.5vp in the final

    Deck Name: Kindred Spirits (Deck created by Noel Giménez Infante)

    Crypt (12 cards, min=18, max=30, avg=6.08)
    ------------------------------------------
    2x Persia, The Beautiful Statue	5   DEM aus obf		 	  Malkavian:3
    1x Anatole, Prophet of Gehenna	8   AUS DEM OBF dom for	 	  Malkavian:2
    1x Rodolfo			8   AUS DEM OBF pro	 bishop	  Malkavian antitribu:3
    1x Kite				7   AUS DEM obf pre	 bishop	  Malkavian antitribu:2
    1x Korah			7   AUS DEM OBF ani	 priscus  Malkavian antitribu:2
    1x Quentin King III		7   AUS DEM obf pre	 prince	  Malkavian:3
    1x Artemis			6   DEM OBF aus cel for	 	  Malkavian antitribu:2
    1x Dolphin Black		6   AUS DEM OBF		 	  Malkavian antitribu:2
    1x Tony				6   AUS DEM dom obf	 	  Malkavian:3
    1x Uncle George			5   DEM aus dom obf	 	  Malkavian antitribu:3
    1x Midget			3   DEM obf pre		 	  Malkavian antitribu:3

    Library (90 cards)
    Master (14; 6 trifle)
    1x Barrens, The
    1x Bleeding the Vine
    1x Direct Intervention
    3x Dreams of the Sphinx
    1x Pentex(TM) Subversion
    1x Secure Haven
    4x Vessel
    2x Wash

    Action (27)
    1x Aranthebes, The Immortal
    9x Call, The
    14x Kindred Spirits
    2x Restructure
    1x Sibyl's Tongue

    Ally (1)
    1x Carlton Van Wyk

    Equipment (1)
    1x Heart of Nizchetus

    Action Modifier (30)
    6x Confusion
    4x Elder Impersonation
    8x Eyes of Chaos
    4x Faceless Night
    4x Lost in Crowds
    4x Spying Mission

    Action Modifier/Combat (7)
    1x Deny
    2x Hide the Mind
    4x Swallowed by the Night

    Action Modifier/Reaction (1)
    1x Random Patterns

    Reaction (9)
    1x Delaying Tactics
    4x On the Qui Vive
    4x Telepathic Misdirection

Top

    Black Forest Base 3
    Hyvinkää, Finland
    September 5th 2020
    2R+F
    14 players
    Niko Vanhatalo
    http://www.vekn.net/event-calendar/event/9667

    -- 1gw5 + 3vp in the final

    Here is a quick report by the Winner of the event Niko Vanhatalo.

    Just your average Ventrue grinder/stickmen with my own personal preferences

    Finals were pretty brutal because every deck was a bleeder in some way or the
    other and there was no clear winner even when it was down to 2 players.
    Players from 1 to 5 were Petri with Anarch stealth bleeder, Jyrkkä with
    Lasombra/Kiasyd stealth bleeder, Pauli with Ventrue grinder, me with my own
    Ventrue grinder and Lasse with Legion and Legionnaire bleeder.  My biggest
    concern was my predator who played pretty much the same deck with like 90% of
    the crypt being the same cards, but we were able to avoid unnecesary contesting
    thanks to table talk. He still contested my Lodin later in the game but was
    ousted pretty fast after that before any real damage to me was done.

    Deck Name: My stick is better than bacon

    Crypt (12 cards, min=18, max=31, avg=6.17)
    ------------------------------------------
    3x Lodin (Olaf Holte)	8   DOM FOR PRE aus pro	 prince	   Ventrue:5
    2x Graham Gottesman	7   DOM FOR obf pre tha	 prince	   Ventrue:5
    2x Victor Donaldson	6   DOM for pre		 prince	   Ventrue:5
    1x Mustafa, The Heir	6   FOR PRE cel dom	 prince	   Ventrue:4
    1x Claus Wegener	5   DOM aus for tha	 	   Tremere:5
    1x Emily Carson		5   DOM for pre		 primogen  Ventrue:5
    1x Jephta Hester	5   DOM FOR aus		 	   Ventrue antitribu:4
    1x Ulrike Rothbart	3   dom for		 	   Ventrue antitribu:4

    Library (88 cards)
    Master (16; 5 trifle)
    1x Anarch Troublemaker
    1x Direct Intervention
    1x Dreams of the Sphinx
    1x Giant's Blood
    1x Golconda: Inner Peace -- Neat card, but never played. Should propably switch for another Dreams or Wash
    1x Misdirection
    1x Papillon
    2x Pentex(TM) Subversion
    2x Perfectionist
    2x Vessel
    2x Villein
    1x Wash

    Action (14)
    1x Dominate Kine
    2x Entrancement
    11x Govern the Unaligned

    Equipment (2)
    2x Heart of Nizchetus

    Political Action (4)
    4x Parity Shift

    Action Modifier (19)
    2x Bonding
    3x Conditioning
    3x Daring the Dawn
    4x Freak Drive
    5x Seduction
    2x Threats

    Reaction (16)
    8x Deflection
    3x On the Qui Vive
    4x Second Tradition: Domain
    1x Wake with Evening's Freshness -- This should be another On the Qui Vive but I was too lazy to find 1 from my collection

    Combat (17)
    5x Hidden Strength
    6x Indomitability
    2x Rolling with the Punches
    4x Weighted Walking Stick

Top

    Aniversário do Biell
    Fortaleza, Brazil
    August 30th 2020
    2R+F
    11 players
    Lucas Raphael
    http://www.vekn.net/event-calendar/event/9681

    -- 1gw4 + 1.5vp in the final

    Deck Name: Tzismice - Augusto

    Crypt (12 cards, min=29, max=38, avg=8.33)
    ------------------------------------------
    1x Lambach				  10  ANI AUS DOM VIC pre  cardinal	Tzimisce:2
    1x Lambach (ADV)			  10  ANI AUS DOM VIC pre  2 votes	Tzimisce:2
    1x Sascha Vykos, The Angel of Caine	  8   AUS THA VIC ani dom  priscus	Tzimisce:2
    1x Sascha Vykos, The Angel of Caine (ADV) 8   AUS THA VIC ani dom  archbishop	Tzimisce:2
    1x John Paleologus			  9   ANI AUS CEL VIC pot  archbishop	Tzimisce:3
    1x Stravinsky				  9   ANI AUS VIC pot	   archbishop	Tzimisce:2
    1x Velya, The Flayer			  9   ANI AUS PRE VIC for  cardinal	Tzimisce:3
    1x Anton				  8   ANI AUS cel obf vic  		Tzimisce:2
    1x Little Tailor of Prague		  8   ANI AUS VIC dem	   		Tzimisce:2
    1x Meshenka				  8   ANI AUS VIC	   priscus	Tzimisce:2
    1x Dragos				  7   ANI AUS vic	   		Tzimisce:2
    1x Caliban				  6   ANI AUS VIC	   		Tzimisce:2

    Library (90 cards)
    Master (15; 4 trifle)
    1x Fame
    1x KRCG News Radio
    1x Library Hunting Ground
    4x Minion Tap
    1x Papillon
    1x Powerbase: Montreal
    1x Sudden Reversal
    1x Tension in the Ranks
    4x Vessel

    Action (2)
    1x Army of Rats
    1x Under Siege

    Ally (2)
    1x Carlton Van Wyk
    1x Procurer

    Equipment (3)
    1x Blade of Enoch
    1x Bowl of Convergence
    1x Heart of Nizchetus

    Retainer (5)
    1x Raptor
    4x Raven Spy

    Reaction (32)
    3x Cats' Guidance
    3x Enhanced Senses
    4x Eyes of Argus
    3x On the Qui Vive
    3x Read the Winds
    6x Sense the Savage Way
    2x Spirit's Touch
    8x Telepathic Misdirection

    Combat (31)
    1x Blood of Acid
    1x Canine Horde
    6x Carrion Crows
    3x Chiropteran Marauder
    4x Drawing Out the Beast
    8x Horrid Form
    3x Inner Essence
    5x Terror Frenzy

Top

    Return from Torpor
    Gdynia, Poland
    August 22nd 2020
    3R+F
    19 players
    Łukasz Ho Thanh
    http://www.vekn.net/event-calendar/event/9660

    -- 2gw7 + 3vp in the final

    Deck Name: Enkidu Anarch
    Description: Another tribute to Bram van Stappen idea:)

    Crypt (12 cards, min=4, max=43, avg=6.08)
    -----------------------------------------
    4x Anarch Convert   1	-none-			 Caitiff:ANY
    3x Enkidu, The Noah 11	ANI CEL OBF POT PRO for	 Gangrel antitribu:4
    3x Matasuntha	    10	ANI AUS CEL FOR PRO	 Gangrel:5
    2x Andre LeRoux	    3	aus			 Toreador:5

    Library (90 cards)
    Master (28; 7 trifle)
    12x Ashur Tablets
    1x Direct Intervention
    2x Dreams of the Sphinx
    1x Fame
    1x Giant's Blood
    2x Parthenon, The
    1x Pentex(TM) Subversion
    1x Powerbase: Montreal
    5x Villein
    1x Wash
    1x Wider View

    Retainer (9)
    1x Mr. Winthrop
    8x Raven Spy

    Action Modifier (5)
    1x Enkil Cog
    2x Forced March
    2x Instantaneous Transformation

    Reaction (18)
    3x Cats' Guidance
    4x Forced Awakening
    4x On the Qui Vive
    7x Sense the Savage Way

    Combat (29)
    1x Claws of the Dead
    10x Diversion
    4x Drawing Out the Beast
    3x Earth Meld
    3x Infernal Pursuit
    3x Psyche!
    5x Taste of Vitae

    Event (1)
    1x Dragonbound

Top

    Skaald
    Fortaleza, Brazil
    August 16th 2020
    2R+F
    10 players
    Lucas Raphael
    http://www.vekn.net/event-calendar/event/9659

    -- 1gw4 + 4vp in the final

    Deck Name: Reins of the Stanislava!

    Crypt (12 cards, min=34, max=44, avg=9.83)
    ------------------------------------------
    4x Stanislava	  11  ANI CEL DOM FOR PRO	   inner circle	 Gangrel:2
    2x Hartmut Stover 10  CEL OBF PRO dom for	   archbishop	 Gangrel antitribu:3
    2x Xaviar (ADV)	  10  ABO ANI FOR PRO aus cel pot  justicar	 Gangrel:3
    2x Ingrid Rossler 9   ANI FOR PRO dom		   prince	 Gangrel:2
    2x Mark Decker	  8   CEL PRO ani for obf pot	   prince	 Gangrel:3

    Library (90 cards)
    Master (20; 6 trifle)
    1x Backways
    1x Coven, The
    1x Dreams of the Sphinx
    1x Ecoterrorists
    1x Ennoia's Theater
    1x Fear of Mekhet
    1x Giant's Blood
    1x Information Highway
    1x Legendary Vampire
    1x Monastery of Shadows
    1x Pentex(TM) Subversion
    5x Villein
    4x Zillah's Valley

    Action (7)
    7x Govern the Unaligned

    Political Action (18)
    1x Anarchist Uprising
    1x Ancient Influence
    1x Ancilla Empowerment
    2x Banishment
    4x Kine Resources Contested
    1x Neonate Breach
    5x Parity Shift
    1x Permanent Vacation
    1x Political Stranglehold
    1x Reins of Power

    Retainer (1)
    1x Homunculus

    Action Modifier (16)
    1x Beast Meld
    4x Earth Control
    1x Enkil Cog
    3x Forced March
    1x Foreshadowing Destruction
    3x Freak Drive
    3x Instantaneous Transformation

    Action Modifier/Combat (2)
    2x Rapid Change

    Action Modifier/Reaction (2)
    2x Murmur of the False Will

    Reaction (12)
    6x Deflection
    3x On the Qui Vive
    3x Second Tradition: Domain

    Combat (12)
    6x Earth Meld
    6x Form of Mist

Top

    Padawan's Tournament II
    Palma de Mallorca, Spain
    August 9th 2020
    3R+F
    17 players
    Juan Luís Molina
    http://www.vekn.net/event-calendar/event/9624

    -- 2gw7 + 2vp in the final

    Deck Name: Unmada/Lutz Gods of the parlaments
    Description: Do what you have to do.
    Thanks to Moisés Ferrer mentor, good player and a big friend.

    Jordi Bestard and Matías Tugores thank you for give me good advices. Maybe I
    should used minion tap instead villeins.. Anyways We played a great final with
    a lot of votes like lasombra, stanislava, Nosferatu... A good day to remember
    with a big community of Methuselahs.

    Crypt (12 cards, min=32, max=44, avg=9.67)
    ------------------------------------------
    4x Lutz von Hohenzollern 11  AUS DEM OBF PRE pot	inner circle	Malkavian:4
    4x Unmada		 10  AUS DEM OBF VIC cel for	justicar	Malkavian:5
    2x Dmitra Ilyanova	 9   CEL FOR POT PRE obf	justicar	Brujah:5
    2x Stavros		 7   AUS OBF PRE dem		priscus		Malkavian antitribu:4

    Library (69 cards)
    Master (16; 6 trifle)
    2x Information Highway
    6x Villein
    8x Zillah's Valley

    Political Action (17)
    1x Anarchist Uprising
    1x Ancilla Empowerment
    2x Banishment
    8x Kine Resources Contested
    4x Parity Shift
    1x Reins of Power

    Action Modifier (19)
    3x Elder Impersonation
    3x Faceless Night
    4x Forgotten Labyrinth
    4x Lost in Crowds
    5x Voter Captivation

    Action Modifier/Combat (3)
    3x Swallowed by the Night

    Reaction (12)
    2x Eyes of Argus
    4x On the Qui Vive
    6x Telepathic Misdirection

    Combat (2)
    2x No Trace

Top

    O Despertar de Fortaleza
    Fortaleza, Brazil
    August 2nd 2020
    2R+F
    12 players
    Cicero Jannyson
    http://www.vekn.net/event-calendar/event/9653

    -- 1gw3 + 3vp in the final

    Deck Name: Weenie Animalismo

    Crypt (12 cards, min=4, max=18, avg=2.5)
    ----------------------------------------
    4x Anarch Convert  1   -none-			Caitiff:ANY
    1x Lord Ashton	   5   ANI for pro		Gangrel:3
    1x Yuri Kerezenski 5   ANI aus for vic	bishop	Tzimisce:4
    1x Beetleman	   4   ANI obf			Nosferatu:4
    1x Bobby Lemon	   4   ANI pro			Gangrel:3
    1x Stick	   3   ANI			Nosferatu antitribu:4
    1x Mouse	   2   ani			Nosferatu:3
    1x Zip		   2   ani			Ravnos:3
    1x Lisa Noble	   1   ani			Caitiff:3

    Library (80 cards)
    Master (17; 2 trifle)
    10x Anarch Revolt
    2x Fame
    3x Parthenon, The
    2x Wash

    Action (16)
    2x Army of Rats
    14x Deep Song

    Reaction (1)
    1x Delaying Tactics

    Combat (46)
    14x Aid from Bats
    1x Backstep
    2x Canine Horde
    12x Carrion Crows
    6x Target Vitals
    5x Taste of Vitae
    6x Terror Frenzy

Top

    Garou Rim: Antediluvian Awakening
    Joensuu, Finland
    August 1st 2020
    3R+F
    16 players
    Tommi Hakomaa
    http://www.vekn.net/event-calendar/event/9646

    -- 1gw4 + 3vp in the final

    Back from quarantine!

    Extremely hard games trough the whole tournament. Surprisingly no one scored
    two Game Wins, and 10 players in total had 1GW.

    Big thanks to everyone joining us from the Helsinki area once again!

    Finals Seating:

      Timo Tahvanainen (Saulot + Inner Circles Bleed/Vote) -->
      Marko Saari (Akunanse Toolbox) -->
      Mari Tiippana (Weenie Dementation) -->
      Tommi Hakomaa (Tupdogs + Nephandus) -->
      Simo Tiippana (Unmada + Undele Vote)

    Deck Name: Tupdog & Nephandus

    Martin Weinmayer's deck with tiny modification

    Crypt (25 cards, min=4, max=20, avg=2.16)
    -----------------------------------------
    16x Tupdog		1    POT VIS		Gargoyle:3
    5x  Antonio d'Erlette	5    THA dom for pot	Tremere antitribu:4
    1x  Janine		4    aus dom tha	Tremere antitribu:4
    1x  Ember Wright	3    aus dom		Tremere antitribu:3
    1x  Keith Moody		3    DOM		Tremere antitribu:4
    1x  Saiz		3    aus dom		Tremere antitribu:3

    Library (87 cards)
    Master (30; 2 trifle)
    12x Ashur Tablets
    1x Direct Intervention
    4x Dreams of the Sphinx
    2x Haven Uncovered
    2x Information Highway
    5x Parthenon, The
    1x Powerbase: Montreal
    2x Wider View
    1x Yawp Court

    Action (1)
    1x Aranthebes, The Immortal

    Ally (8)
    8x Nephandus

    Action Modifier (1)
    1x Conditioning

    Reaction (12)
    7x Deflection
    2x Delaying Tactics
    3x On the Qui Vive

    Combat (32)
    6x Brick by Brick
    8x Immortal Grapple
    8x Raking Talons
    4x Target Vitals
    6x Torn Signpost

    Event (3)
    1x FBI Special Affairs Division
    2x Unmasking, The

Top

    4th Elder Library War
    Espoo, Finland
    July 24th 2020
    2R+F
    17 players
    Otso Saariluoma
    http://www.vekn.net/event-calendar/event/9632

    -- 2gw8 + 2vp in the final
    Deck Name: Schwerpunkt Principle
    Author: Otso Saariluoma
    Description: Based on Jens Johansson's list from 2012.

    Crypt (12 cards, min=16, max=32, avg=6.08)
    ------------------------------------------
    2x Emerson Bridges		   8   DOM FOR PRE pot	    prince  Ventrue:1
    2x Sir Walter Nash		   7   DOM FOR PRE	    prince  Ventrue:1
    1x Wilhelm Waldburg		   9   DOM FOR PRE aus cel  prince  Ventrue:2
    1x Timothy Crowley		   7   FOR PRE ani dom	    prince  Ventrue:1
    1x Vanessa			   6   DOM FOR aus pre	    	    Ventrue antitribu:2
    1x Jazz Wentworth		   5   PRE dom for	    	    Ventrue:1
    1x Ranjan Rishi, Camarilla Scholar 5   DOM PRE for	    	    Ventrue:2
    1x Ingrid Russo			   4   DOM for		    	    Ventrue antitribu:2
    1x Violette Prentiss		   4   PRE dom		    	    Ventrue:1
    1x Gideon Fontaine		   3   PRE		    	    Ventrue:1

    Library (82 cards)
    Master (12; 2 trifle)
    1x Anarch Troublemaker
    1x Blood Doll
    1x Dreams of the Sphinx
    1x Fear of Mekhet
    1x Giant's Blood
    1x Jake Washington
    1x Legendary Vampire
    1x Misdirection
    1x Pentex(TM) Subversion
    1x Ventrue Headquarters
    1x Vessel
    1x Wider View

    Action (18)
    2x Enchant Kindred
    2x Entrancement
    9x Govern the Unaligned
    3x Mind Numb
    2x Scouting Mission

    Equipment (1)
    1x Heart of Nizchetus

    Political Action (10)
    1x Anarchist Uprising
    1x Conservative Agitation
    4x Kine Resources Contested
    1x Neonate Breach
    3x Parity Shift

    Action Modifier (25)
    3x Bonding
    4x Conditioning
    2x Daring the Dawn
    1x Foreshadowing Destruction
    12x Freak Drive
    1x Perfect Paragon
    2x Voter Captivation

    Action Modifier/Combat (1)
    1x Force of Personality

    Reaction (7)
    5x Deflection
    2x Second Tradition: Domain

    Combat (8)
    8x Majesty

Top

    Crusade: Moss
    Moss, Norway
    July 12th 2020
    2R+F
    10 players
    Joachim Randa
    http://www.vekn.net/event-calendar/event/9642

    -- 1gw5 + 4vp in the final

    Deck Name: The John and Jane doe's collective

    Crypt (12 cards, min=4, max=8, avg=1.42)
    ----------------------------------------
    1x Christine Boscacci		   2   dom vic	Pander:2
    1x Marciana Giovanni, Investigator 2   dom	Giovanni:2
    1x Mustafa Rahman		   2   dom	Tremere:2
    1x Ohanna			   2   dom	Malkavian:2
    1x Samson			   2   dom	Ventrue antitribu:2
    1x Antoinette DuChamp		   1   cel pre	Caitiff:2
    1x Franciscus			   1   aus	Caitiff:2
    1x Huang, Blood Cultist		   1   pro	Pander:2
    1x March Halcyon		   1   for	Pander:2
    1x Navar McClaren		   1   ani	Caitiff:1
    1x Nik				   1   cel	Caitiff:1
    1x Royce			   1   dom	Pander:2

    Library (90 cards)
    Master (17; 2 trifle)
    2x Dreams of the Sphinx
    6x Effective Management
    2x Information Highway
    1x Jake Washington
    2x Not to Be
    1x Pentex(TM) Subversion
    1x Sudden Reversal
    2x Wash

    Action (28)
    1x Aranthebes, The Immortal
    25x Computer Hacking
    2x Thin-Blooded Seer

    Ally (1)
    1x Mylan Horseed

    Equipment (7)
    7x Flash Grenade

    Action Modifier (4)
    2x Conditioning
    2x Leverage

    Reaction (12)
    4x Deflection
    4x Delaying Tactics
    1x On the Qui Vive
    3x Wake with Evening's Freshness

    Combat (21)
    7x Concealed Weapon
    5x Fake Out
    5x Target Vitals
    4x Weighted Walking Stick

Top

    Summer Moon
    Palma de Mallorca, Spain
    June 28th 2020
    3R+F
    27 players
    Moisés Ferrer
    http://www.vekn.net/event-calendar/event/9621

    -- 1gw6 + 5vp in the final

    Deck Name: Lasombra Nocturns
    Author: Moises Ferrer

    Crypt (12 cards, min=17, max=29, avg=5.67)
    ------------------------------------------
    2x Onaedo		 6   DOM OBT aus pot	  	  Lasombra:4
    2x Ermenegildo, The Rake 5   DOM OBT pot	  	  Lasombra:4
    1x Conrad Adoula	 8   DOM OBT POT ani cel  	  Lasombra:4
    1x Henri Lavenant	 7   DOM OBT pot qui	  	  Lasombra:3
    1x Lord Vauxhall	 7   DOM OBT POT THA	  	  Lasombra:4
    1x Tobias Smith		 7   DOM OBT PRE pot	  	  Lasombra:3
    1x Andrew Emory		 5   OBT aus dom pot	  bishop  Lasombra:4
    1x Banjoko		 5   DOM obt pot	  	  Lasombra:3
    1x Leila Monroe		 4   dom obt pre	  	  Lasombra:4
    1x Lucy Markowitz	 3   dom obt		  	  Lasombra:4

    Library (77 cards)
    Master (11; 1 trifle)
    1x Coven, The
    2x Dreams of the Sphinx
    1x Elysian Fields
    1x Giant's Blood
    1x Jake Washington
    4x Path of Night, The
    1x Pentex(TM) Subversion

    Action (16)
    16x Govern the Unaligned

    Ally (10)
    10x Nocturn

    Action Modifier (26)
    2x Blanket of Night
    4x Bonding
    6x Conditioning
    2x Foreshadowing Destruction
    6x Shadow Play
    6x Shroud of Absence

    Reaction (12)
    6x Deflection
    2x Delaying Tactics
    4x On the Qui Vive

    Event (2)
    2x Unmasking, The

Top

    Advent of Gehenna
    Kragujevac, Serbia
    June 7th 2020
    3R+F
    10 players
    Nikica Novakovic
    http://www.vekn.net/event-calendar/event/9618

    -- 2gw8.5 + 4vp in the final

    Deck Name: Malgorzata, our Lord and Misstress
    Author: Miloš Krstić

    Get Malgorzata first,
    then use her special to get Lord Tremere, so you have some staying power,
    and then Mistress Fanchon to fetch you Heart and other goodies.

    Crypt (12 cards, min=36, max=44, avg=10.17)
    -------------------------------------------
    5x Malgorzata	    9	AUS DOM THA VIC pre	 priscus	Tremere antitribu:4
    4x Lord Tremere	    11	ANI AUS DOM THA VIC obe	 		Tremere:5
    3x Mistress Fanchon 11	AUS CEL DOM OBF THA VIC	 inner circle	Tremere:4

    Library (80 cards)
    Master (16; 5 trifle)
    3x Dreams of the Sphinx
    1x Giant's Blood
    3x Information Highway
    1x Monastery of Shadows
    5x Villein
    3x Zillah's Valley

    Ally (1)
    1x Carlton Van Wyk

    Equipment (1)
    1x Heart of Nizchetus

    Political Action (5)
    1x Anarchist Uprising
    1x Ancilla Empowerment
    2x Banishment
    1x Reins of Power

    Action Modifier (9)
    4x Changeling
    5x Mirror Walk

    Action Modifier/Combat (5)
    5x Plasmic Form

    Reaction (25)
    2x Deflection
    3x Eagle's Sight
    7x Eyes of Argus
    3x My Enemy's Enemy
    4x On the Qui Vive
    6x Telepathic Misdirection

    Combat (18)
    3x Amaranth
    2x Blood Rage
    1x Breath of the Dragon
    8x Chiropteran Marauder
    2x Quick Jab
    2x Theft of Vitae

Top

    Road to EC: Field Training
    Joensuu, Finland
    March 14th 2020
    3R+F
    13 players
    Esa-Matti Smolander
    http://www.vekn.net/event-calendar/event/9542

    -- 1gw4.5 + 3vp in the final

    Third tournament of our "Road to EC" series. The faith of the next event is
    still unclear, as it is not known how the ongoing situation is going to
    develop.

    Great amount of players considering everything that is going on. Super tight
    games all around, unexpectedly a lot of voting and not that much bleeders. One
    of our players had to leave after the first round, due to personal reasons, but
    we continued with 12 players!

    Big thanks to Tommi, Antti and Jyri for coming to Joensuu all the way from
    Helsinki area!

    Finals Seating:
    Aapo Järvelin (Al'Muntathir Black Hand Bleed) --> Tommi Hakomaa (Osebo Combat/Wall)
       --> Esa-Matti Smolander (Stanislava Vote&Bleed) --> Jyri Puhakka (Anson Guns)
       --> Antti Penttilä (Jacques Rouge + Baali Vote)

    Deck Name: Stanislava Vote/Bleed v1.6

    Crypt (13 cards, min=35, max=44, avg=9.92)
    ------------------------------------------
    5x Stanislava	  11  ANI CEL DOM FOR PRO	   inner circle	 Gangrel:2
    4x Ingrid Rossler 9   ANI FOR PRO dom		   prince	 Gangrel:2
    1x Genevieve	  10  ANI FOR PRO aus dom	   priscus	 Gangrel antitribu:2
    1x Hartmut Stover 10  CEL OBF PRO dom for	   archbishop	 Gangrel antitribu:3
    1x Xaviar (ADV)	  10  ABO ANI FOR PRO aus cel pot  justicar	 Gangrel:3
    1x Mark Decker	  8   CEL PRO ani for obf pot	   prince	 Gangrel:3

    Library (70 cards)
    Master (14; 7 trifle)
    1x Backways
    1x Direct Intervention
    1x Dreams of the Sphinx
    1x Giant's Blood
    1x Information Highway
    1x Monastery of Shadows
    1x Papillon
    5x Villein
    1x Wash
    1x Wider View

    Action (6)
    6x Govern the Unaligned

    Political Action (13)
    2x Anarchist Uprising
    1x Ancient Influence
    2x Ancilla Empowerment
    2x Banishment
    1x Kine Resources Contested
    3x Parity Shift
    1x Political Stranglehold
    1x Reins of Power

    Action Modifier (18)
    3x Conditioning
    4x Earth Control
    1x Enkil Cog
    4x Forced March
    2x Freak Drive
    4x Instantaneous Transformation

    Action Modifier/Combat (1)
    1x Rapid Change

    Reaction (9)
    6x Deflection
    3x On the Qui Vive

    Combat (9)
    3x Earth Meld
    6x Form of Mist

Top

    Birthday Blood Party
    Szczecin, Poland
    March 14th 2020
    3R+F
    10 players
    Łukasz Ho Thanh
    http://www.vekn.net/event-calendar/event/9592

    -- 3gw10 + 2.5vp in the final

    Deck Name: Tariq Wall Rush 2.0
    Description: In previous version I had problem with cost of the flamethrowers.
    So, adding Ashur Tablets was essential to solve this problem

    Crypt (12 cards, min=4, max=28, avg=4.5)
    ----------------------------------------
    4x Tariq, The Silent	   7   AUS FOR OBF QUI cel  Assamite:2
    1x Tariq, The Silent (ADV) 7   AUS FOR OBF QUI cel  Assamite:2
    4x Anarch Convert	   1   -none-		    Caitiff:ANY
    1x Sheila Mezarin	   6   AUS PRE cel for	    Toreador antitribu:2
    1x Miriam Benyona	   5   AUS for obe	    Salubri:2
    1x Maldavis (ADV)	   4   AUS for pre	    Caitiff:3

    Library (90 cards)
    Master (22; 4 trifle)
    9x Ashur Tablets
    1x Direct Intervention
    1x Fame
    1x Fragment of the Book of Nod
    2x Parthenon, The
    1x Pentex(TM) Subversion
    1x Powerbase: Montreal
    1x Rack, The
    1x Tension in the Ranks
    4x Vessel

    Action (1)
    1x Atonement

    Equipment (9)
    2x Bowl of Convergence
    6x Flamethrower
    1x Sport Bike

    Retainer (1)
    1x Mr. Winthrop

    Reaction (36)
    5x Black Sunrise
    4x Eagle's Sight
    3x Enhanced Senses
    7x Eyes of Argus
    2x Forced Awakening
    4x Guardian Vigil
    3x My Enemy's Enemy
    3x On the Qui Vive
    5x Telepathic Misdirection

    Combat (21)
    5x Amaranth
    5x Disguised Weapon
    11x Diversion

Top

    Revolutionary Council
    Fortaleza, Brazil
    March 8th 2020
    2R+F
    13 players
    Cicero Jannyson
    http://www.vekn.net/event-calendar/event/9600

    -- 1gw4.5 + 3vp in the final

    Deck Name: True Bruja
    Description: My example

    Crypt (12 cards, min=4, max=40, avg=4.92)
    -----------------------------------------
    5x Shalmath	  10  POT PRE TEM  True Brujah:6
    2x Anarch Convert 1   -none-	   Caitiff:ANY
    1x Andre LeRoux	  3   aus	   Toreador:5
    1x Donald Cargill 1   aus	   Caitiff:5
    1x Freddy Gage	  1   pot	   Caitiff:5
    1x Iris Bennett	  1   pro	   Caitiff:5
    1x Walker Grimes  1   ani	   Caitiff:5

    Library (75 cards)
    Master (11; 4 trifle)
    1x Giant's Blood
    1x KRCG News Radio
    2x Perfectionist
    2x Rack, The
    1x Tabriz Assembly
    2x Vessel
    2x Wider View

    Action (13)
    1x Aranthebes, The Immortal
    1x Clotho's Gift
    2x Entrancement
    9x Summon History

    Ally (8)
    1x Carlton Van Wyk
    1x Harzomatuili
    1x High Top
    1x Mylan Horseed
    1x Ossian
    1x Ponticulus
    1x Remnant of the Endless Storm
    1x Renegade Garou

    Equipment (9)
    1x Ankara Citadel, Turkey, The
    3x Heart of Nizchetus
    1x Laptop Computer
    1x Sargon Fragment, The
    3x Starshell Grenade Launcher

    Action Modifier (16)
    12x Domain of Evernight
    4x Enkil Cog

    Combat (16)
    6x Decapitate
    10x Outside the Hourglass

    Event (2)
    2x Unmasking, The

Top

    Life is a Samedi
    Palma de Mallorca, Spain
    March 8th 2020
    3R+F
    11 players
    Antonio Seguí
    http://www.vekn.net/event-calendar/event/9572

    -- 1gw3.5 + 3.5vp in the final

    Deck Name: Nosfi principes el bueno

    Crypt (12 cards, min=22, max=39, avg=7.75)
    ------------------------------------------
    3x Cock Robin		10  ANI OBF POT aus for	 justicar  Nosferatu:3
    3x Casino Reeds		9   ANI OBF POT cel dem	 prince	   Nosferatu:3
    2x Murat		7   OBF POT ser		 prince	   Nosferatu:2
    2x Nikolaus Vermeulen	7   POT ani for obf	 prince	   Nosferatu:2
    1x Calebros, The Martyr	5   ANI obf pot		 prince	   Nosferatu:2
    1x Clarissa Steinburgen	3   ani obf		 	   Nosferatu:3

    Library (90 cards)
    Master (18; 4 trifle)
    1x Archon Investigation
    1x Direct Intervention
    1x Elysium: The Palace of Versailles
    1x Giant's Blood
    2x Information Highway
    1x Labyrinth, The
    1x Legendary Vampire
    1x Papillon
    1x Powerbase: Montreal
    1x Protected Resources
    1x Slum Hunting Ground
    1x Smiling Jack, The Anarch
    3x Vessel
    1x Warsaw Station
    1x Wider View

    Action (8)
    4x Fifth Tradition: Hospitality
    3x Fourth Tradition: The Accounting
    1x Judgment: Camarilla Segregation

    Equipment (6)
    2x Flak Jacket
    1x Kevlar Vest
    1x Palatial Estate
    2x Sniper Rifle

    Political Action (13)
    1x Ancient Influence
    1x Ancilla Empowerment
    2x Banishment
    6x Kine Resources Contested
    2x Parity Shift
    1x Political Stranglehold

    Action Modifier (14)
    4x Cloak the Gathering
    4x Elder Impersonation
    6x Forgotten Labyrinth

    Reaction (21)
    5x Cats' Guidance
    2x Confusion of the Eye
    2x On the Qui Vive
    12x Second Tradition: Domain

    Combat (10)
    6x Carrion Crows
    4x No Trace

Top
Back to the deck lists.